@@ -1,16 +1,22 @@
 import hashlib
 import logging
 from typing import List
+from typing import Tuple
+
+from peek_core_user._private.PluginNames import userPluginTuplePrefix
+
+from peek_core_user._private.server.auth_connectors.AuthABC import AuthABC
 
-from peek_core_user._private.server.auth_connectors.InternalAuth import (
-    InternalAuth,
-)
 from peek_core_user._private.storage.InternalUserTuple import InternalUserTuple
 from peek_core_user._private.storage.LdapSetting import LdapSetting
 from peek_core_user._private.storage.Setting import (
     globalSetting,
     LDAP_VERIFY_SSL,
 )
+from peek_core_user.tuples.constants.UserAuthTargetEnum import (
+    UserAuthTargetEnum,
+)
+
 from twisted.cred.error import LoginFailed
 
 __author__ = "synerty"
@@ -50,14 +56,8 @@ class LdapNotEnabledError(Exception):
     pass
 
 
-class LdapAuth:
-    FOR_ADMIN = InternalAuth.FOR_ADMIN
-    FOR_OFFICE = InternalAuth.FOR_OFFICE
-    FOR_FIELD = InternalAuth.FOR_FIELD
-
-    def checkPassBlocking(
-        self, dbSession, userName, password, forService: int
-    ) -> List[str]:
+class LdapAuth(AuthABC):
+    def checkPassBlocking(self, dbSession, userName, password, forService):
         """Login User
 
         :param forService:
@@ -75,7 +75,7 @@ class LdapAuth:
             ldap.set_option(ldap.OPT_X_TLS_REQUIRE_CERT, ldap.OPT_X_TLS_NEVER)
 
         if not ldapSettings:
-            raise Exception("No LDAP servers configured.")
+            raise Exception("LDAPAuth: No LDAP servers configured.")
 
         firstException = None
 
@@ -94,7 +94,7 @@ class LdapAuth:
 
             else:
                 raise Exception(
-                    "InternalAuth:Unhandled forService type %s" % forService
+                    "LDAPAuth: Unhandled forService type %s" % forService
                 )
 
             try:
@@ -108,11 +108,11 @@ class LdapAuth:
         if firstException:
             raise firstException
 
-        raise LoginFailed("No LDAP providers found for this service")
+        raise LoginFailed("LDAPAuth: No LDAP providers found for this service")
 
     def _tryLdap(
         self, dbSession, userName, password, ldapSetting: LdapSetting
-    ) -> List[str]:
+    ) -> Tuple[List[str], InternalUserTuple]:
         try:
 
             conn = ldap.initialize(ldapSetting.ldapUri)
@@ -143,7 +143,9 @@ class LdapAuth:
                 )
 
             if not ldapBases:
-                raise LoginFailed("LDAP OU and/or CN search paths must be set.")
+                raise LoginFailed(
+                    "LDAPAuth: LDAP OU and/or CN search paths must be set."
+                )
 
             userDetails = None
             for ldapBase in ldapBases:
@@ -163,19 +165,61 @@ class LdapAuth:
 
         except ldap.NO_SUCH_OBJECT:
             raise LoginFailed(
-                "An internal error occurred, ask admin to check Attune logs"
+                "LDAPAuth: An internal error occurred, ask admin to check "
+                "Attune logs"
             )
 
         except ldap.INVALID_CREDENTIALS:
-            raise LoginFailed("Username or password is incorrect")
+            raise LoginFailed("LDAPAuth: Username or password is incorrect")
 
         if not userDetails:
-            raise LoginFailed("User doesn't belong to the correct CN/OUs")
+            raise LoginFailed(
+                "LDAPAuth: User doesn't belong to the correct CN/OUs"
+            )
 
         userDetails = userDetails[0][1]
 
+        distinguishedName = userDetails.get("distinguishedName")[0].decode()
+        primaryGroupId = userDetails.get("primaryGroupID")[0].decode()
+        objectSid = userDetails.get("objectSid")[0]
+        # python-ldap doesn't include key `memberOf` in search result
+        #  if the user doesn't belong to any groups.
+        memberOfSet = set(userDetails.get("memberOf", []))
+
+        decodedSid = LdapAuth._decodeSid(objectSid)
+        primaryGroupSid = (
+            "-".join(decodedSid.split("-")[:-1]) + "-" + primaryGroupId
+        )
+
+        ldapFilter = "(objectSid=%s)" % primaryGroupSid
+        primGroupDetails = conn.search_st(
+            dcParts, ldap.SCOPE_SUBTREE, ldapFilter, None, 0, 10
+        )
+        memberOfSet.add(primGroupDetails[0][1].get("distinguishedName")[0])
+
+        # find all it's groups and groups of those groups
+        # The magic number in this filter allows us to fetch the groups of
+        # a group.
+        ldapFilter = (
+            "(&(objectCategory=group)(member:1.2.840.113556.1.4.1941:=%s))"
+            % (distinguishedName,)
+        )
+        groupDetails = conn.search_st(
+            ",".join(distinguishedName.split(",")[1:]),
+            ldap.SCOPE_SUBTREE,
+            ldapFilter,
+            None,
+            0,
+            10,
+        )
+
+        if groupDetails:
+            for group in groupDetails:
+                groupMemberOf = group[1].get("memberOf", [])
+                memberOfSet.update(groupMemberOf)
+
         groups = []
-        for memberOf in userDetails["memberOf"]:
+        for memberOf in memberOfSet:
             group = memberOf.decode().split(",")[0]
             if "=" in group:
                 group = group.split("=")[1]
@@ -202,7 +246,7 @@ class LdapAuth:
             if not ldapGroups & set(groups):
                 raise LoginFailed("User is not apart of an authorised group")
 
-        self._makeOrCreateInternalUserBlocking(
+        newInternalUser = self._maybeCreateInternalUserBlocking(
             dbSession,
             userName,
             userTitle,
@@ -211,30 +255,61 @@ class LdapAuth:
             ldapSetting.ldapTitle,
         )
 
-        return groups
+        return groups, newInternalUser
 
-    def _makeOrCreateInternalUserBlocking(
+    def _decodeSid(sid: [bytes]) -> str:
+        strSid = "S-"
+        sid = iter(sid)
+
+        # Byte 0 is the revision
+        revision = next(sid)
+        strSid += "%s" % (revision,)
+
+        # Byte 1 is the count of sub-authorities
+        countSubAuths = next(sid)
+
+        # Byte 2-7 (big endian) form the 48-bit authority code
+        bytes27 = [next(sid) for _ in range(2, 8)]
+        authority = int.from_bytes(bytes27, byteorder="big")
+        strSid += "-%s" % (authority,)
+
+        for _ in range(countSubAuths):
+            # Each is 4 bytes (32-bits) in little endian
+            subAuthBytes = [next(sid) for _ in range(4)]
+            subAuth = int.from_bytes(subAuthBytes, byteorder="little")
+            strSid += "-%s" % (subAuth,)
+
+        return strSid
+
+    def _maybeCreateInternalUserBlocking(
         self, dbSession, userName, userTitle, userUuid, email, ldapName
-    ):
+    ) -> InternalUserTuple:
 
         internalUser = (
             dbSession.query(InternalUserTuple)
             .filter(InternalUserTuple.userUuid == userUuid)
-            .all()
+            .first()
         )
 
+        # do no create, return the existing user
         if internalUser:
-            return
+            return internalUser
 
         newInternalUser = InternalUserTuple(
             userName=userName,
+            userKey=userName.lower(),
             userTitle="%s (%s)" % (userTitle, ldapName),
             userUuid=userUuid,
             email=email,
+            authenticationTarget=UserAuthTargetEnum.LDAP,
+            importSource="LDAP",
+            # importHash e.g. 'peek_core_user.LDAPAuth:<md5 hash>'
+            importHash=f"{userPluginTuplePrefix}{self.__class__.__name__}:{userUuid}",
         )
 
         dbSession.add(newInternalUser)
         dbSession.commit()
+        return newInternalUser
 
     def _makeLdapBase(self, ldapFolders, userName, propertyName):
         try:
