@@ -3,14 +3,15 @@ from datetime import datetime
 from typing import List
 
 import pytz
+from peek_core_device.server.DeviceApiABC import DeviceApiABC
 from twisted.cred.error import LoginFailed
 from twisted.internet import reactor
-from twisted.internet.defer import Deferred, inlineCallbacks
+from twisted.internet.defer import Deferred
+from twisted.internet.defer import inlineCallbacks
 from vortex.DeferUtil import deferToThreadWrapWithLogger
 from vortex.TupleSelector import TupleSelector
 from vortex.handler.TupleDataObservableHandler import TupleDataObservableHandler
 
-from peek_core_device.server.DeviceApiABC import DeviceApiABC
 from peek_core_user._private.server.api.UserFieldHookApi import UserFieldHookApi
 from peek_core_user._private.server.api.UserInfoApi import UserInfoApi
 from peek_core_user._private.server.auth_connectors.InternalAuth import (
@@ -18,11 +19,13 @@ from peek_core_user._private.server.auth_connectors.InternalAuth import (
 )
 from peek_core_user._private.server.auth_connectors.LdapAuth import LdapAuth
 from peek_core_user._private.storage.Setting import (
-    globalSetting,
     INTERNAL_AUTH_ENABLED_FOR_FIELD,
-    LDAP_AUTH_ENABLED,
+)
+from peek_core_user._private.storage.Setting import (
     INTERNAL_AUTH_ENABLED_FOR_OFFICE,
 )
+from peek_core_user._private.storage.Setting import LDAP_AUTH_ENABLED
+from peek_core_user._private.storage.Setting import globalSetting
 from peek_core_user._private.storage.UserLoggedIn import UserLoggedIn
 from peek_core_user._private.tuples.LoggedInUserStatusTuple import (
     LoggedInUserStatusTuple,
@@ -47,6 +50,27 @@ USER_ALREADY_LOGGED_ON_KEY = "pl-user.USER_ALREADY_LOGGED_ON"
 DEVICE_ALREADY_LOGGED_ON_KEY = "pl-user.DEVICE_ALREADY_LOGGED_ON_KEY"
 
 
+class _ForceLogout:
+    def __init__(self, userUuid, deviceToken):
+        self._userUuid = userUuid
+        self._deviceToken = deviceToken
+
+    def forceDbLogout(self, ormSession):
+        ormSession.query(UserLoggedIn).filter(
+            UserLoggedIn.userUuid == self._userUuid
+        ).filter(UserLoggedIn.deviceToken == self._deviceToken).delete(
+            synchronize_session=False
+        )
+
+    def notify(self, clientTupleObservable):
+        clientTupleObservable.notifyOfTupleUpdate(
+            TupleSelector(
+                UserLoggedInTuple.tupleType(),
+                selector=dict(deviceToken=self._deviceToken),
+            )
+        )
+
+
 class LoginLogoutController:
     def __init__(
         self, deviceApi: DeviceApiABC, dbSessionCreator: DbSessionCreator
@@ -220,6 +244,8 @@ class LoginLogoutController:
         isFieldService = loginTuple.isFieldService
         allowMultipleLogins = isFieldService
 
+        forceLogouter = None
+
         responseTuple = UserLoginResponseTuple(
             userName=userName,
             userToken="Not implemented",
@@ -289,9 +315,13 @@ class LoginLogoutController:
             # If the user is logged in, but not to this client device, raise exception
             if allowMultipleLogins and userLoggedIn and not sameDevice:
                 if USER_ALREADY_LOGGED_ON_KEY in acceptedWarningKeys:
-                    self._forceLogout(
-                        ormSession, userUuid, loggedInElsewhere.deviceToken
+
+                    forceLogouter = _ForceLogout(
+                        userUuid, loggedInElsewhere.deviceToken
                     )
+
+                    forceLogouter.forceDbLogout(ormSession)
+
                     userLoggedIn = False
 
                 else:
@@ -315,11 +345,12 @@ class LoginLogoutController:
 
                     # Else, The old device has been deleted,
                     # Just let them login to the same device.
-                    self._forceLogout(
-                        ormSession,
+
+                    forceLogouter = _ForceLogout(
                         loggedInElsewhere.userUuid,
                         loggedInElsewhere.deviceToken,
                     )
+                    forceLogouter.forceDbLogout(ormSession)
 
             # If we're logging into the same device, but already logged in
             if sameDevice:  # Logging into the same device
@@ -344,11 +375,11 @@ class LoginLogoutController:
             if anotherUserOnThatDevice:
                 anotherUserOnThatDevice = anotherUserOnThatDevice[0]
                 if DEVICE_ALREADY_LOGGED_ON_KEY in acceptedWarningKeys:
-                    self._forceLogout(
-                        ormSession,
+                    forceLogouter = _ForceLogout(
                         anotherUserOnThatDevice.userUuid,
                         anotherUserOnThatDevice.deviceToken,
                     )
+                    forceLogouter.forceDbLogout(ormSession)
 
                 else:
                     responseTuple.setFailed()
@@ -386,6 +417,9 @@ class LoginLogoutController:
         finally:
             ormSession.close()
 
+            if forceLogouter:
+                forceLogouter.notify(self._clientTupleObservable)
+
     @inlineCallbacks
     def login(self, loginTuple: UserLoginAction):
         """
